
#define NatC1Letters "I"  
#define NatC2Letters "i" 

/*

   NatChCas()  : National Change Case ( Convert UPPER<->LOWER case chars to each other )
               
   Syntax      : NatChCas( <cOneCaseString> [,<lUpper>] ) -> <cOtherCaseString> 
               
   Arguments   : <cOneCaseString> : String to convert
                 <lUpper> : If .T.  (default)  lower to upper, else upper to lower 
                 conversion will be made.
               
   Returns     : <cOtherCaseString> : othercase equivalent of <cOneCaseString>
               
   Required    : NatC1Letters and NatC2Letters constants (or variables) including 
                 national upper and lower letters.
                 
   Coution     : None-letter characters left intact
               
   Category    : Strings

   Description : If contents of NatC1Letters uppercase and NatC2Letters lowercase letters,
                 function works like UPPER(); in reverse order it works like LOWER().
                
                 In other words, always converts NatC1Letters characters to NatC2Letters.  
                 
                 Attention to <lUpper>.
                 
   Author      : Bicahi Esgici ( esgici <at> gmail )
               
   Scope       : Public domain, all rights reserved.
               
   History     : 2011 10 : First release
                 
*/

FUNCTION NatChCas(;                       // National Change Case ( UPPER<->LOWER )
                   cInStr,;   // String to convert
                   lUpper )   // .T. : to upper, .F. : to lower
                   
   LOCAL nStrPtr := 0,;
         cRetVal := '',;
         cSrcChr := ''

   lUpper  := IF( HB_ISNIL( lUpper ), .T., lUpper )      
   
   cRetVal := cInStr 
      
   FOR nStrPtr := 1 TO LEN( NatC2Letters )
     cSrcChr := SUBS( NatC2Letters, nStrPtr,1)
     WHILE cSrcChr $ cRetVal
        cRetVal := STUFF( cRetVal, AT( cSrcChr, cRetVal), 1, SUBS( NatC1Letters, nStrPtr, 1))
     ENDDO
   NEXT nStrPtr 

   cRetVal := IF( lUpper, UPPER( cRetVal ), LOWER( cRetVal ) )  
   
RETURN cRetVal  // NatChCas()
   
*-._.-._.-._.-._.-._.-._.-._.-._.-._.-._.-._.-._-._.-._.-._.-._.-._.-._.-._.-._.-._.-._.-._.-._


#define NatUprLetters "I"  
#define NatLowLetters "i" 


/*

   NatUpper() : National UPPER; Convert lowercase National letters to capitals
              
   Syntax     : NatUpper(<cLowString>) -> <cUpprString>
              
   Argument   : <cLowString> : String to convert
              
   Returns    : <cUpprString> : Uppercase equivalent of <cLowString>
              
   Required   : NatUprLetters and NatLowLetters constants (or variables) including national upper
                and lower letters.
              
   Coution    : None-letter characters left intact
              
   Category   : Strings
              
   Author      : Bicahi Esgici ( esgici <at> gmail )
               
   Scope       : Public domain, all rights reserved.
               
   History    : 2011 10 : First release
                 
*/

FUNCTION NatUpper( cLowStr )                       // National UPPER()

   LOCAL nStrPtr := 0,;
         cRetVal := cLowStr,;
         cSrcChr := ''

   FOR nStrPtr := 1 TO LEN( NatLowLetters )
     cSrcChr := SUBS( NatLowLetters, nStrPtr,1)
     WHILE cSrcChr $ cRetVal
        cRetVal := STUFF( cRetVal, AT( cSrcChr, cRetVal), 1, SUBS( NatUprLetters, nStrPtr, 1))
     ENDDO
   NEXT

   cRetVal := UPPER( cRetVal )
   
RETURN cRetVal  // NatUpper()
   
*-._.-._.-._.-._.-._.-._.-._.-._.-._.-._.-._.-._-._.-._.-._.-._.-._.-._.-._.-._.-._.-._.-._.-._


#define NatUprLetters "I"  
#define NatLowLetters "i" 

/*

   NatLower() : National LOWER; Convert upper case National letters to lower case
              
   Syntax     : NatUpper( <cUprString> ) -> <cLowrString>
              
   Argument   : <cUprString> : String to convert
              
   Returns    : <cLowrString> : Lower case equivalent of <cUprString>
              
   Required   : NatUprLetters and NatLowLetters constants (or variables) including national upper
                and lower letters.
              
   Coution    : None-letter characters left intact
              
   Category   : Strings
              
   Author     : Bicahi Esgici ( esgici <at> gmail )
               
   Scope      : Public domain, all rights reserved.
               
   History    : 2011 10 : First release
                 
*/

FUNCTION NatLower( cUprStr )                       // National LOWER()

   LOCAL nStrPtr := 0,;
         cRetVal := cUprStr,;
         cSrcChr := ''

   FOR nStrPtr := 1 TO LEN( NatUprLetters )
     cSrcChr := SUBS( NatUprLetters, nStrPtr,1)
     WHILE cSrcChr $ cRetVal
        cRetVal := STUFF( cRetVal, AT( cSrcChr, cRetVal), 1, SUBS( NatLowLetters, nStrPtr, 1))
     ENDDO
   NEXT

   cRetVal := LOWER( cRetVal )
   
RETURN cRetVal  // NatLower()
   
*-._.-._.-._.-._.-._.-._.-._.-._.-._.-._.-._.-._-._.-._.-._.-._.-._.-._.-._.-._.-._.-._.-._.-._

